==============
Topic Modeling
==============


.. autoclass:: orangecontrib.text.topics.LdaWrapper
   :members: fit, transform
   :special-members: __init__


.. autoclass:: orangecontrib.text.topics.LsiWrapper
   :members: fit, transform
   :special-members: __init__



.. autoclass:: orangecontrib.text.topics.HdpWrapper
   :members: fit, transform
   :special-members: __init__
